==> v10.5.1.zip: brewman/overlord/src/app/journal/journal-dialog.component.ts <==
import { Component, Inject, OnInit } from '@angular/core';
import { FormControl, FormGroup } from '@angular/forms';
import { MatAutocompleteSelectedEvent } from '@angular/material/autocomplete';
import { MAT_DIALOG_DATA, MatDialogRef } from '@angular/material/dialog';
import { Observable, of as observableOf } from 'rxjs';
import { debounceTime, distinctUntilChanged, map, switchMap } from 'rxjs/operators';

import { Account } from '../core/account';
import { AccountBalance } from '../core/account-balance';
import { AccountService } from '../core/account.service';
import { Journal } from '../core/journal';
import { MathService } from '../shared/math.service';

@Component({
  selector: 'app-journal-dialog',
  templateUrl: './journal-dialog.component.html',
  styleUrls: ['./journal-dialog.component.css'],
})
export class JournalDialogComponent implements OnInit {
  accounts: Observable<Account[]>;
  form: FormGroup<{
    debit: FormControl<number>;
    account: FormControl<string | null>;
    amount: FormControl<string>;
  }>;

  account: Account = new Account();
  accBal: AccountBalance | null = null;

  constructor(
    public dialogRef: MatDialogRef<JournalDialogComponent>,
    @Inject(MAT_DIALOG_DATA) public data: { journal: Journal; date: string },
    private math: MathService,
    private accountSer: AccountService,
  ) {
    this.form = new FormGroup({
      debit: new FormControl(1, { nonNullable: true }),
      account: new FormControl(''),
      amount: new FormControl('', { nonNullable: true }),
    });
    this.accBal = null;
    // Setup Account Autocomplete
    this.accounts = this.form.controls.account.valueChanges.pipe(
      map((x) => (x !== null && x.length >= 1 ? x : null)),
      debounceTime(150),
      distinctUntilChanged(),
      switchMap((x) => (x === null ? observableOf([]) : this.accountSer.autocomplete(x))),
    );
  }

  ngOnInit() {
    this.form.setValue({
      debit: this.data.journal.debit,
      account: this.data.journal.account.name,
      amount: `${this.data.journal.amount}`,
    });
    this.account = this.data.journal.account;
  }

  displayFn(account?: Account): string {
    return account ? account.name : '';
  }

  accountSelected(event: MatAutocompleteSelectedEvent): void {
    const account = event.option.value;
    this.account = account;
    this.accountSer.balance(account.id as string, this.data.date).subscribe((v) => {
      this.accBal = v;
    });
  }

  accept(): void {
    const formValue = this.form.value;
    const amount = this.math.journalAmount(formValue.amount, formValue.debit!);
    this.data.journal.debit = amount.debit;
    this.data.journal.account = this.account;
    this.data.journal.amount = amount.amount;
    this.dialogRef.close(this.data.journal);
  }
}

==> v10.5.3.zip: brewman/overlord/src/app/journal/journal-dialog.component.ts <==
import { Component, Inject, OnInit } from '@angular/core';
import { FormControl, FormGroup } from '@angular/forms';
import { MatAutocompleteSelectedEvent } from '@angular/material/autocomplete';
import { MAT_DIALOG_DATA, MatDialogRef } from '@angular/material/dialog';
import { Observable, of as observableOf } from 'rxjs';
import { debounceTime, distinctUntilChanged, switchMap } from 'rxjs/operators';

import { Account } from '../core/account';
import { AccountBalance } from '../core/account-balance';
import { AccountService } from '../core/account.service';
import { Journal } from '../core/journal';
import { MathService } from '../shared/math.service';

@Component({
  selector: 'app-journal-dialog',
  templateUrl: './journal-dialog.component.html',
  styleUrls: ['./journal-dialog.component.css'],
})
export class JournalDialogComponent implements OnInit {
  accounts: Observable<Account[]>;
  form: FormGroup<{
    debit: FormControl<number>;
    account: FormControl<string | null>;
    amount: FormControl<string>;
  }>;

  account: Account = new Account();
  accBal: AccountBalance | null = null;

  constructor(
    public dialogRef: MatDialogRef<JournalDialogComponent>,
    @Inject(MAT_DIALOG_DATA) public data: { journal: Journal; date: string },
    private math: MathService,
    private accountSer: AccountService,
  ) {
    this.form = new FormGroup({
      debit: new FormControl(1, { nonNullable: true }),
      account: new FormControl(''),
      amount: new FormControl('', { nonNullable: true }),
    });
    this.accBal = null;
    // Setup Account Autocomplete
    this.accounts = this.form.controls.account.valueChanges.pipe(
      debounceTime(150),
      distinctUntilChanged(),
      switchMap((x) => (x === null ? observableOf([]) : this.accountSer.autocomplete(x))),
    );
  }

  ngOnInit() {
    this.form.setValue({
      debit: this.data.journal.debit,
      account: this.data.journal.account.name,
      amount: `${this.data.journal.amount}`,
    });
    this.account = this.data.journal.account;
  }

  displayFn(account?: Account | string): string {
    return !account ? '' : typeof account === 'string' ? account : account.name;
  }

  accountSelected(event: MatAutocompleteSelectedEvent): void {
    const account = event.option.value as Account;
    this.account = account;
    this.accountSer.balance(account.id as string, this.data.date).subscribe((v) => {
      this.accBal = v;
    });
  }

  accept(): void {
    const formValue = this.form.value;
    const amount = this.math.journalAmount(formValue.amount, formValue.debit ?? 1);
    this.data.journal.debit = amount.debit;
    this.data.journal.account = this.account;
    this.data.journal.amount = amount.amount;
    this.dialogRef.close(this.data.journal);
  }
}
